@@ -23,7 +23,7 @@ extern char		s48_Spending_eventsPS;
 extern char		s48_Spending_interruptPS;
 extern void		s48_disable_interruptsB(void);
 extern void		s48_enable_interruptsB(void);
-extern void		s48_set_os_signals(s48_value list);
+extern void		s48_set_os_signal(s48_value type, s48_value argument);
 
 /* imported and exported bindings */	  
 extern void		s48_define_exported_binding(char *, s48_value);
