@@ -54,7 +54,6 @@
 
 (define-interface primitives-interface
   (export add-finalizer!
-	  add-pending-channel
 	  call-external-value
 	  checked-record-ref
 	  checked-record-set!
@@ -141,9 +140,7 @@
 	  byte-vector-length
 	  byte-vector-ref
 	  byte-vector-set!
-	  make-byte-vector
-	  
-	  byte-vector))
+	  make-byte-vector))
 
 ; Same again, but with old names for compatibility.
 
@@ -200,7 +197,6 @@
   (export lock?
 	  make-lock
 	  obtain-lock
-	  obtain-lock-multiple
 	  maybe-obtain-lock
 	  release-lock
 	  lock-owner-uid))    ;really should be internal
@@ -547,7 +543,6 @@
 	  output-channel+closer->port	;big/socket.scm
 	  
 	  ; call WAIT-FOR-CHANNEL with interrupts disabled
-	  wait-for-channels
 	  wait-for-channel		;big/socket.scm
 
 	  port->channel			;posix
@@ -573,10 +568,12 @@
 
 	  current-thread
 
-	  enqueue-thread!
+	  make-thread-queue
 	  thread-queue-empty?
-	  maybe-dequeue-thread!
-	  block-on-queue
+	  enqueue-thread!
+	  multiple-enqueue-thread!
+	  dequeue-thread!
+	  remove-thread-from-queues!
 
 	  event-pending?
 	  get-next-event!
@@ -588,16 +585,13 @@
 	  
 	  block
 	  make-ready
-	  set-thread-cell! clear-thread-cell!
 	  spawn-on-scheduler spawn-on-root
 	  wait
 	  upcall propogate-upcall
 	  interrupt-thread
 	  kill-thread!
-	  terminate-thread!
 
 	  wake-some-threads
-	  register-dozer
 
 	  all-threads                   ; for command-levels
 
@@ -615,9 +609,8 @@
           decrement-counter!))
 
 (define-interface queues-interface
-  (export make-queue enqueue! dequeue! maybe-dequeue! queue-empty?
-	  queue? queue->list queue-front queue-length
-	  delete-from-queue! on-queue?))
+  (export make-queue enqueue! dequeue! queue-empty?
+	  queue? queue->list queue-length delete-from-queue!))
 
 (define-interface exceptions-interface
   (export define-exception-handler
@@ -655,7 +648,7 @@
 
 (define-interface rts-sigevents-internal-interface
   (export waiting-for-sigevent?
-	  with-sigevents))
+	  initialize-sigevents!))
 
 (define-interface writing-interface
   (export write
@@ -1181,7 +1174,6 @@
 
 (define-interface evaluation-interface
   (export eval load load-into eval-from-file
-          load-port
 	  ; eval-scanned-forms
 	  ))
 
