@@ -63,7 +63,6 @@
 	session-data
 	define-record-types
 	threads threads-internal
-	queues
 	scheduler
 	interrupts
 	weak
@@ -409,13 +408,12 @@
 
 (define-structure placeholders placeholder-interface
   (open scheme-level-1 define-record-types
-	threads threads-internal queues
+	threads threads-internal
 	interrupts
 	signals)
   (files (big placeholder))
   (optimize auto-integrate))
 
-
 ;----------------
 ; Big Scheme
 
@@ -424,6 +422,10 @@
 	signals)		;call-error
   (files (big random)))
 
+(define-structure sort (export sort-list sort-list!)
+  (open scheme-level-2)
+  (files (big sort)))
+
 (define-structure pp (export p pretty-print define-indentation)
   (open scheme-level-2
         tables
@@ -492,87 +494,6 @@
 	threads thread-cells fluids)
   (files (big thread-fluid)))
 
-;;; Package defs for the Scheme Underground sorting package,
-
-;;; The general sort package:
-
-(define-structure sorting sorting-interface
-  (open scheme
-	list-merge-sort
-	vector-heap-sort
-	vector-merge-sort
-	sorted
-	delete-neighbor-duplicates)
-  (files (sort sort))
-  (optimize auto-integrate))
-
-(define-structure sorted sorted-interface
-  (open scheme
-	vector-utils)
-  (files (sort sortp))
-  (optimize auto-integrate))
-
-(define-structure delete-neighbor-duplicates delete-neighbor-duplicates-interface
-  (open scheme
-	receiving
-	vector-utils)
-  (files (sort delndups))
-  (optimize auto-integrate))
-
-(define-structure binary-searches binary-searches-interface
-  (open scheme
-	vector-utils)
-  (files (sort vbinsearch)))
-
-(define-structure list-merge-sort list-merge-sort-interface
-  (open scheme
-	receiving
-	(subset signals (error)))
-  (files (sort lmsort))
-  (optimize auto-integrate))
-
-(define-structure vector-merge-sort vector-merge-sort-interface
-  (open scheme
-	receiving
-	vector-utils
-	vector-insertion-sort-internal)
-  (files (sort vmsort))
-  (optimize auto-integrate))
-
-(define-structure vector-heap-sort vector-heap-sort-interface
-  (open scheme
-	receiving
-	vector-utils)
-  (files (sort vhsort))
-  (optimize auto-integrate))
-
-(define-structures ((vector-insertion-sort vector-insertion-sort-interface)
-		    (vector-insertion-sort-internal
-		     vector-insertion-sort-internal-interface))
-  (open scheme
-	vector-utils)
-  (files (sort visort))
-  (optimize auto-integrate))
-
-(define-structure vector-utils (export vector-copy
-				       vector-portion-copy
-				       vector-portion-copy!
-				       vector-start+end
-				       vectors-start+end-2)
-  (open scheme)
-  (files (sort vector-util)))
-
-;;; end Package defs for the Scheme Underground sorting package,
-
-(define-structure sort (export sort-list sort-list!)
-  (open scheme-level-2
-	sorting)
-  (begin
-    (define (sort-list l obj-<)
-      (list-sort obj-< l))
-    (define (sort-list! l obj-<)
-      (list-sort! obj-< l))))
-
 (define-structure big-util big-util-interface
   (open scheme-level-2
 	formats
@@ -773,7 +694,7 @@
 ; SRFI-4 - needs hacks to the reader
 
 (define-structure srfi-5 (export (let :syntax))
-  (open (modify scheme-level-2 (rename (let standard-let))))
+  (open (modify scheme-level-2 (hide let)))
   (files (srfi srfi-5)))
 
 (define-structure srfi-6 (export open-input-string
@@ -806,10 +727,7 @@
   (begin
     (define available-srfis
       '(srfi-1 srfi-2 srfi-5 srfi-6 srfi-7 srfi-8 srfi-9
-	srfi-11 srfi-13 srfi-14 srfi-16 srfi-17 srfi-19 srfi-23
-	srfi-25 srfi-26 srfi-27 srfi-28 
-        srfi-30 srfi-31	srfi-37
-        srfi-42))
+	srfi-11 srfi-13 srfi-14 srfi-16 srfi-17 srfi-23))
 
     ; Some SRFI's redefine Scheme variables.
     (define shadowed
@@ -885,79 +803,14 @@
   (files (srfi srfi-17)))
 
 ; SRFI-18 - no implementation given
-
-(define (make-srfi-19 scheme-with-scsh)
-  (structure srfi-19-interface
-     (open scheme-with-scsh
-           (subset srfi-1 (reverse!))
-           srfi-6
-           srfi-8
-           signals
-           srfi-9)
-     (files (srfi srfi-19))))
-
+; SRFI-19 - implementation is specific to MzScheme
 ; SRFI-20 - withdrawn
 ; SRFI-21 - no implementation given
-; SRFI-22 - no implementation given
+; SRFI-22 - not final yet
 
 (define-structure srfi-23 (export error)
   (open (subset signals (error))))
 
-; SRFI-24 - withdrawn
-
-(define-structure srfi-25 (export 
-			   array? make-array shape array 
-			   array-rank 
-			   array-start array-end 
-			   array-ref array-set! share-array)
-  (open scheme
-	srfi-23
-	srfi-9)
-  (files (srfi srfi-25)))
-  
-
-(define-structure srfi-26 (export ((cut cute) :syntax))
-  (open scheme)
-  (files (srfi srfi-26)))
-
-(define-structure srfi-27 srfi-27-interface
-  (open
-   scheme-level-1
-   floatnums
-   external-calls
-   (subset srfi-9 (define-record-type)) 
-   (subset srfi-23 (error)))
-;; scsh doesn't have S48's posix subsystem yet:
-;   (subset posix-time (current-time)) 
-;   (subset posix (time-seconds)))
-  (files (srfi srfi-27)))
-
-(define-structure srfi-28 (export format)
-  (open scheme
-	srfi-23
-	srfi-6)
-  (files (srfi srfi-28)))
-
-; SRFI-29 - requires access to the current locale
-
-; SRFI-30 - scheme/rts/read.scm contains the reader for #|...|# comments
-
-(define-structure srfi-31 srfi-31-interface
-  (open scheme)
-  (files (srfi srfi-31)))
-
-(define-structure srfi-37 srfi-37-interface
-  (open scheme 
-	srfi-9 
-	srfi-11)
-  (files (srfi srfi-37)))
-
-; Eager Comprehensions
-
-(define-structure srfi-42 srfi-42-interface
-  (open scheme
-	srfi-23)
-  (files (srfi srfi-42)))
 ; ... end of package definitions.
 
 ; Temporary compatibility stuff
@@ -1020,17 +873,7 @@
 	    search-trees
 	    sicp
 	    sockets
-
 	    sort
-	    delete-neighbor-duplicates
-	    binary-searches
-	    sorted
-	    list-merge-sort
-	    vector-merge-sort
-	    vector-heap-sort
-	    vector-insertion-sort
-	    sorting
-
 	    strong
 	    thread-fluids
 	    traverse
@@ -1053,10 +896,7 @@
             ; SRFI packages
 	    srfi-1 srfi-2 srfi-5 srfi-6 srfi-7 srfi-8 srfi-9
 	    srfi-11 srfi-13 srfi-14 srfi-16 srfi-17
-	    srfi-23 srfi-25 srfi-26 srfi-27 srfi-28
-	    srfi-31 srfi-37
-            srfi-42
+	    srfi-23
 	    )
 	   :structure)
-          make-srfi-19
 	  ((define-signature define-package) :syntax)))
