@@ -101,7 +101,7 @@
 	channels low-channels
 	architecture code-vectors wind
 	define-record-types
-	queues threads threads-internal locks cells
+	queues threads threads-internal locks
 	exceptions interrupts
 	ascii ports util
 	session-data
@@ -224,9 +224,8 @@
 
 (define-structures ((rts-sigevents rts-sigevents-interface)
 		    (rts-sigevents-internal rts-sigevents-internal-interface))
-  (open scheme-level-1 define-record-types queues
+  (open scheme-level-1 define-record-types
 	threads threads-internal
-	wind
 	interrupts
 	architecture)
   (files (rts sigevents))
@@ -237,7 +236,7 @@
 
 (define-structures ((threads threads-interface)
 		    (threads-internal threads-internal-interface))
-  (open scheme-level-1 enumerated define-record-types queues cells
+  (open scheme-level-1 enumerated define-record-types queues
 	interrupts
         wind
         fluids
@@ -259,7 +258,6 @@
 (define-structure scheduler scheduler-interface
   (open scheme-level-1 threads threads-internal locks
 	enumerated enum-case
-	queues
 	debug-messages
 	signals)       		;error
   (files (rts scheduler)))
@@ -269,7 +267,6 @@
 					 scheme-exit-now
 					 call-when-deadlocked!)
   (open scheme-level-1 threads threads-internal scheduler structure-refs
-	queues
 	session-data
 	signals        		;error
 	handle			;with-handler
@@ -303,8 +300,7 @@
 	 (unspecific))))))
 
 (define-structure queues queues-interface
-  (open scheme-level-1 define-record-types signals
-	debug-messages)
+  (open scheme-level-1 define-record-types signals)
   (files (big queue))
   (optimize auto-integrate))
 
@@ -318,7 +314,7 @@
 ;  (optimize auto-integrate))
 
 (define-structure locks locks-interface
-  (open scheme-level-1 define-record-types queues interrupts threads threads-internal)
+  (open scheme-level-1 define-record-types interrupts threads threads-internal)
   (optimize auto-integrate)
   (files (rts lock)))
 
@@ -330,7 +326,7 @@
 	fluids-internal	 ;initialize-dynamic-state!
 	exceptions	 ;initialize-exceptions!
 	interrupts	 ;initialize-interrupts!
-	rts-sigevents-internal  ;with-sigevents
+	rts-sigevents-internal  ;initialize-sigevents!
 	records-internal ;initialize-records!
 	export-the-record-type	;just what it says
 	threads-internal ;start threads
