@@ -181,13 +181,6 @@
 	       ((port-handler-close (port-handler port)) (port-data port))))))
       (call-error "invalid argument" close-input-port port)))
 	
-;; Flushing the port may raise an error. If the port is marked closed
-;; before, subsequent calls will never close the underlying channel.
-;; This installs an error handler before calling REALLY-FORCE-OUTPUT,
-;; the handler will try to close the port and raise the error
-;; afterwards. The inner close has an additional error handler which
-;; will invoke the original handler.
-
 (define (close-output-port port)
   (if (output-port? port)
       (protect-port-op
@@ -196,16 +189,7 @@
 	   (if (open-output-port? port)
 	       (begin
 		 (make-output-port-closed! port)
-		 (with-handler 
-		  (lambda (condition more)
-		    (with-handler 
-		     (lambda (cond2 more2)
-		       (more))
-		     (lambda ()
-		       ((port-handler-close (port-handler port)) (port-data port))
-		       (more))))
-		  (lambda ()
-		    (really-force-output port)))
+		 (really-force-output port)
 		 ((port-handler-close (port-handler port)) (port-data port))))))
       (call-error "invalid argument" close-output-port port)))
 
@@ -565,43 +549,32 @@
 ; all non-empty buffers, because the system has nothing to do and is going
 ; to pause while waiting for external events.
 
-(define (output-port-forcers use-flushed?-flags? . maybe-ignore-port-locks?)
-  (let ((ignore-port-locks? (if (null? maybe-ignore-port-locks?) #f #t)))
-    (let loop ((next (cdr *flush-these-ports*))
-	       (last *flush-these-ports*)
-	       (thunks '()))
-      (if (null? next)
-	  thunks
-	  (let ((port (weak-pointer-ref (car next))))
-	    (cond ((or (not port)	; GCed or closed
-		       (not (open-output-port? port))) ;  so drop it from the list
-		   (set-cdr! last (cdr next))
-		   (loop (cdr next) last thunks))
-		  (ignore-port-locks?
-		   (cond ((and use-flushed?-flags? ; flushed recently
-			       (port-flushed? port))
-			  (set-port-flushed?! port #f)
-			  (loop (cdr next) next thunks))
-			 ((< 0 (port-index port)) ; non-empty
-			  (loop (cdr next) next
-				(cons (make-forcing-thunk port ignore-port-locks?)
-				      thunks)))
-			 (else (loop (cdr next) next thunks))))
-		  ((not (maybe-obtain-port-lock port)) ; locked
-		   (loop (cdr next) next thunks))
-		  ((and use-flushed?-flags? ; flushed recently
-			(port-flushed? port))
-		   (set-port-flushed?! port #f)
-		   (release-port-lock port)
-		   (loop (cdr next) next thunks))
-		  ((< 0 (port-index port)) ; non-empty
-		   (release-port-lock port)
-		   (loop (cdr next) next
-			 (cons (make-forcing-thunk port ignore-port-locks?)
-			       thunks)))
-		  (else			; empty
-		   (release-port-lock port)
-		   (loop (cdr next) next thunks))))))))
+(define (output-port-forcers use-flushed?-flags?)
+  (let loop ((next (cdr *flush-these-ports*))
+             (last *flush-these-ports*)
+             (thunks '()))
+    (if (null? next)
+        thunks
+        (let ((port (weak-pointer-ref (car next))))
+          (cond ((or (not port)                      ; GCed or closed
+                     (not (open-output-port? port))) ;  so drop it from the list
+                 (set-cdr! last (cdr next))
+                 (loop (cdr next) last thunks))
+                ((not (maybe-obtain-port-lock port)) ; locked
+                 (loop (cdr next) next thunks))
+                ((and use-flushed?-flags?            ; flushed recently
+                      (port-flushed? port))
+                 (set-port-flushed?! port #f)
+                 (release-port-lock port)
+                 (loop (cdr next) next thunks))
+                ((< 0 (port-index port))              ; non-empty
+                 (release-port-lock port)
+                 (loop (cdr next) next
+		       (cons (make-forcing-thunk port)
+			     thunks)))
+                (else                                 ; empty
+                 (release-port-lock port)
+                 (loop (cdr next) next thunks)))))))
 
 ; Returns a list of the current ports that are flushed whenever.
 ; This is used to flush channel ports before forking.
@@ -628,20 +601,18 @@
 ; Write out PORT's buffer.  If a problem occurs it is reported and PORT
 ; is closed.
 
-(define (make-forcing-thunk port ignore-port-lock?)
+(define (make-forcing-thunk port)
   (lambda ()
     (if (and (report-errors-as-warnings
 	      (lambda ()
-		(cond ((maybe-obtain-port-lock port)
-		       (with-handler
-			(lambda (condition punt)
-			  (release-port-lock port)
-			  (punt))
-			(lambda ()
-			  (really-force-output port)
-			  (release-port-lock port))))
-		      (ignore-port-lock?
-		       (really-force-output port))))
+		(if (maybe-obtain-port-lock port)
+		    (with-handler
+		     (lambda (condition punt)
+		       (release-port-lock port)
+		       (punt))
+		     (lambda ()
+		       (really-force-output port)
+		       (release-port-lock port)))))
 	      "error when flushing buffer; closing port"
 	      port)
 	     (open-output-port? port))
