@@ -74,7 +74,7 @@
        (decrement-counter! thread-count)
        (next-thread))
       ((out-of-time)
-       (enqueue! runnable thread)
+       (enqueue-thread! runnable thread)
        (next-thread))
 
       ;; the thread keeps running
@@ -94,13 +94,13 @@
     (or (event-handler event event-data)
 	(enum-case event-type event
 	  ((runnable)
-	   (enqueue! runnable (car event-data)))
+	   (enqueue-thread! runnable (car event-data)))
 	  ((spawned)
 	   (increment-counter! thread-count)
-	   (enqueue! runnable
-		     (make-thread (car event-data)
-				  dynamic-env
-				  (cadr event-data))))
+	   (enqueue-thread! runnable
+			    (make-thread (car event-data)
+					 dynamic-env
+					 (cadr event-data))))
  	  ((narrowed)
 	   (handle-narrow-event quantum dynamic-env event-data))
 	  ((no-event)
@@ -112,7 +112,7 @@
 		  event-handler)))))
 
   (define (next-thread)
-    (if (queue-empty? runnable)
+    (if (thread-queue-empty? runnable)
 	(call-with-values
 	 get-next-event!
 	 (lambda (event . data)
@@ -123,7 +123,7 @@
 		  (next-thread))
 		 (else
 		  (values #f 0)))))   ; scheduler quits
-	(values (dequeue! runnable)
+	(values (dequeue-thread! runnable)
 		quantum)))
 
   thread-event-handler)
@@ -134,13 +134,13 @@
     (obtain-lock lock)
     (spawn
      (lambda ()
-       (let ((runnable (make-queue))
+       (let ((runnable (make-thread-queue))
 	     (thread (make-thread (car event-data)
 				  dynamic-env
 				  (cadr event-data)))
 	     (thread-count (make-counter)))
        
-	 (enqueue! runnable thread)
+	 (enqueue-thread! runnable thread)
 	 (increment-counter! thread-count)
        
 	 (run-threads
