@@ -183,7 +183,6 @@
   (close-channel 1)
   (channel-maybe-read 5)
   (channel-maybe-write 4)
-  (add-pending-channel 2)
   (channel-ready? 1)
   (channel-abort 1)             ; stop channel operation
   (open-channels-list)		; return a list of the open channels
@@ -241,8 +240,7 @@
   (alarm           ; order matters - higher priority first
    keyboard
    post-gc         ; handler is passed a list of finalizers
-   i/o-read-completion  ; handler is passed channel and status
-   i/o-write-completion  ; handler is passed channel and status
+   i/o-completion  ; handler is passed channel and status
    os-signal       
    ))
 
