@@ -173,8 +173,9 @@ s48_value scheme_accept(s48_value sockfd_tagged, s48_value family)
 	      s48_raise_out_of_memory_error();
 	    return S48_FALSE;
 	  }
-	
-	return(s48_enter_fixnum (newsockfd));
+	fcntl(newsockfd, F_SETFL, O_NONBLOCK);
+	return(s48_cons (s48_enter_fixnum (newsockfd),
+			 s48_enter_string (name.sun_path)));
 	break;
       }
     case AF_INET: 
