@@ -1,5 +1,5 @@
-#!/afs/informatik.uni-tuebingen.de/i386_fbsd43/scsh-0.6.1//lib/scsh/scshvm \
--o /afs/informatik.uni-tuebingen.de/i386_fbsd43/scsh-0.6.1//lib/scsh/scshvm -h 8000000 -i /afs/informatik.uni-tuebingen.de/i386_fbsd43/scsh-0.6.1//lib/scsh/scsh.image -lm /afs/informatik.uni-tuebingen.de/i386_fbsd43/scsh-0.6.1//lib/scsh/vm/ps-interface.scm -lm /afs/informatik.uni-tuebingen.de/i386_fbsd43/scsh-0.6.1//lib/scsh/vm/interfaces.scm -lm /afs/informatik.uni-tuebingen.de/i386_fbsd43/scsh-0.6.1//lib/scsh/vm/package-defs.scm -lm /afs/informatik.uni-tuebingen.de/i386_fbsd43/scsh-0.6.1//lib/scsh/vm/s48-package-defs.scm -dm -m static-heaps -e static-heap-linker -s
+#!/usr/local/lib/scsh/scshvm \
+-o /usr/local/lib/scsh/scshvm -h 8000000 -i /usr/local/lib/scsh/scsh.image -lm /usr/local/lib/scsh/vm/ps-interface.scm -lm /usr/local/lib/scsh/vm/interfaces.scm -lm /usr/local/lib/scsh/vm/package-defs.scm -lm /usr/local/lib/scsh/vm/s48-package-defs.scm -dm -m static-heaps -e static-heap-linker -s
 !#
 
 #!
@@ -138,12 +138,12 @@ For testing load this at a scsh prompt
 	 options
 	 (or (options:ld-flags options)
 	     (getenv "LDFLAGS") 
-	     "-rdynamic"))
+	     "-L/afs/wsi/sun4x_58/lib -L/afs/informatik.uni-tuebingen.de/home/gasbichl/sun4x_58/lib -L/afs/wsi/sun4x_57/lib -L/afs/informatik.uni-tuebingen.de/home/gasbichl/sun4x_57/lib -L/afs/wsi/sun4x_56/lib -L/afs/informatik.uni-tuebingen.de/home/gasbichl/sun4x_56/lib -L/afs/wsi/sun4x_55/lib -L/afs/informatik.uni-tuebingen.de/home/gasbichl/sun4x_55/lib"))
 	(set-options:libraries
 	 options
 	 (or (options:libraries options)
 	     (getenv "LIBS") 
-	     "-lcrypt -lm "))
+	     "-lelf -lsocket -lgen -lnsl -ldl -lm "))
 	options))
 
 ;;; usage reporting
@@ -452,7 +452,7 @@ For testing load this at a scsh prompt
 					 (cons "static.o"
 					       l)))))
 			       (options:args-parser options)
-			       '("-L" "/afs/informatik.uni-tuebingen.de/i386_fbsd43/scsh-0.6.1//lib/scsh" "-lscshvm")
+			       '("-L" "/usr/local/lib/scsh" "-lscshvm")
 			       libs)))
 	  (message command)
 	  (run (,@command)))))
