@@ -64,8 +64,8 @@ s48_value scheme_tcgetattr(s48_value sch_fd, s48_value sch_control_chars)
     sch_oflag = s48_enter_integer(t.c_oflag);
     sch_cflag = s48_enter_integer(t.c_cflag);
     sch_lflag = s48_enter_integer(t.c_lflag);
-    sch_ispeed = cfgetispeed(&t);
-    sch_ospeed = cfgetospeed(&t);
+    sch_ispeed = s48_enter_integer(cfgetispeed(&t));
+    sch_ospeed = s48_enter_integer(cfgetospeed(&t));
 
     sch_retval = s48_list_6 (sch_iflag, sch_oflag, sch_cflag, sch_lflag,
 			     sch_ispeed, sch_ospeed);
